@@ -4,9 +4,8 @@ use Pcore -role;
 
 package Pcore::App::PSGI;
 
-use Pcore -class;
+use Pcore -class, -ansi;
 use Pcore::Util::Scalar qw[is_glob];
-use Term::ANSIColor qw[:constants];
 use Plack::Builder qw[];
 use Pcore::AppX::HasAppX;
 
@@ -282,11 +281,11 @@ sub store_runtime_cfg ($self) {
 ## -----SOURCE FILTER LOG BEGIN-----
 ##
 ## PerlCritic profile "pcore-script" policy violations:
-## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
-## │ Sev. │ Lines                │ Policy                                                                                                         │
-## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 225                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
-## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
+## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
+## | Sev. | Lines                | Policy                                                                                                         |
+## |======+======================+================================================================================================================|
+## |    3 | 224                  | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
+## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
 __END__
